| holideh-package | R Documentation |
Convenience date tools for identifying weekends, business days, and Canadian holidays, including R wrappers for the Canada Holidays API https://canada-holidays.ca/.
Maintainer: Adam Shen adamshen1@gmail.com [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.