| get_holidays | R Documentation |
Get all holidays for a given year. Best used for obtaining a list of federal holidays.
get_holidays(year = NULL, federal = NULL, optional = NULL)
year |
The year for which holidays should be retrieved, between 2013 and 2038. The default,
|
federal |
A boolean indicating whether only federal holidays should be retrieved. The
default, |
optional |
A boolean indicating whether optional (non-legislated) holidays should be
retrieved. The default, |
A tibble with columns:
<date> The date when the holiday occurs.
<date> The date when the holiday is observed (celebrated). For example,
if Christmas Day falls on a Sunday, it is observed (celebrated) on the proceeding Monday.
<chr> The name of the holiday, in English.
<chr> The name of the holiday, in French.
<lgl> Whether the holiday is a federal holiday.
<int> The id of the holiday.
<list> A list of tibbles containing information on the provinces observing
the holiday and source links.
get_province(), Canada Holidays API
if (interactive()) {
get_holidays()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.