| is_bizday | R Documentation |
In a vector of dates, detect the business days (i.e. exclude holidays and weekends).
is_bizday(x, holidays, weekend = c("Sat", "Sun"))
x |
A vector of dates or date-times. If date-times are supplied, the date component will be extracted. |
holidays |
A vector of dates that are holidays. |
weekend |
A character vector of three-letter abbreviations of weekday names indicating days
that should be considered a weekend. Acceptable values are: |
Holiday dates can be obtained using get_holidays(), get_province(), or by defining a custom
vector of holidays.
A logical vector of length equal to x.
is_holiday(), is_weekend(), count_bizdays()
library(lubridate)
dates <- seq.Date(from = ymd("2025-12-20"), to = ymd("2025-12-31"), by = "1 day")
winter_holidays <- ymd(c("2025-12-25", "2025-12-26"))
rlang::set_names(is_bizday(dates, holidays = winter_holidays), dates)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.